#!/usr/bin/env bash

# Script to check whether build.sh would result in a different  set of files.
# This is currently only used in the CI.
# Placed in the docker directory because it can be refactored to provision
# the docker image.

# https://betterdev.blog/minimal-safe-bash-script-template/
# Cannot use -u due to openjdk:
# https://github.com/conda-forge/openjdk-feedstock/issues/87
set -Eeo pipefail
set -x

# The conda package should be build first with
# conda build --no-test --output-folder .conda-bld .

# Create environment. TODO: refactor.
# Some operating systems skip `.bashrc` when running in non-interactive mode,
# thereby forgoing the conda initialization, so do it explicitly here.
#eval "$(conda shell.bash hook)"
#conda create -n micadowiseci -y
#conda activate micadowiseci

# Install locally build image.
# The index is not available on the CI, so rebuild it.
#conda index .conda-bld
# Install development version, otherwise build.sh will attempt to modify
# the installed files.
# TODO: Somehow ensure build.sh will only ever attempt to change local files.
#conda install -c "file://$(pwd)/.conda-bld/" --only-deps -y micado
#conda develop src
#cp -r conda-recipe/prefix/* "${CONDA_PREFIX}"

# Build the files locally.
bash build.sh

# The SVG and TIKZ figure creation is unstable. Therefore they are allowed
# to differ as long as the DITAA files are identical.
# TODO: Ensure that the figure generation *is* stable. Or
# TODO: Only change SVG/TIKZ figures for which the DITAA file has changed. Or
# TODO: Only allow generation of figures on a machine that generates identical
#       figures as the CI machine does. E.g. check that first with a difficult
#       ditaa figures. Or
# TODO: Replace ditaa with svgbob!
#if git diff --exit-code --quiet docs/source/generated/*.ditaa ; then
#    git checkout -- docs/source/generated/*.svg
#    git checkout -- docs/source/generated/*_tikz.tex
#fi

# Exit with an error code if there are still differences left.
git diff --exit-code
