#!/usr/bin/env bash
# Install all dependencies required to install the MICADO pipeline
# on a conda installation.
# E.g. to be used on the MicadoWISE CI.

# https://betterdev.blog/minimal-safe-bash-script-template/
set -Eeuo pipefail

script_dir=$(cd "$(dirname "${BASH_SOURCE[0]}")" &>/dev/null && pwd -P)

# Set environment variables.
source "${script_dir}/set_environment.sh"

echo "Downloading files to ${TOINSTALLDIR}"
echo "Installing software to ${ESOPIPELINE}"

mkdir -p "${TOINSTALLDIR}"
mkdir -p "${ESOPIPELINE}"

pushd "${TOINSTALLDIR}" || exit

# TODO: Have some way to specify another authentication.
#       E.g. put the credentials in set_environment.sh.
git clone https://CI:${MICADOPIPELINECITOKEN}@gitlab.astro-wise.org/micado/micadopipeline.git
pushd micadopipeline
# TODO: Remove this hardcoded version number again
git checkout 9048f40f

pushd micadom
svn checkout ${SVN_USERNAME_OPTION} ${SVN_PASSWORD_OPTION} https://svnhq2.hq.eso.org/p2/trunk/Pipelines/common/pipedoc
popd

pushd micadop
svn checkout ${SVN_USERNAME_OPTION} ${SVN_PASSWORD_OPTION} https://svnhq2.hq.eso.org/p2/tags/Pipelines/common/hdrl/hdrl-1.2.0 hdrl
svn checkout ${SVN_USERNAME_OPTION} ${SVN_PASSWORD_OPTION} https://svnhq2.hq.eso.org/p2/trunk/Pipelines/common/irplib
svn checkout ${SVN_USERNAME_OPTION} ${SVN_PASSWORD_OPTION} https://svnhq2.hq.eso.org/p2/trunk/Pipelines/common/m4macros
svn checkout ${SVN_USERNAME_OPTION} ${SVN_PASSWORD_OPTION} https://svnhq2.hq.eso.org/p2/trunk/Pipelines/common/regtests
popd

pushd micadop
./bootstrap
LD_LIBRARY_PATH="${ESOPIPELINE}/lib:$(dirname $(which gcc))/../lib" LDFLAGS="-L${ESOPIPELINE}/lib -L${ESOPIPELINE}/lib" LIBS="-lcfitsio -lgomp -lcext" CPPFLAGS="-I$(dirname $(which gcc))/../include" ./configure --prefix=$ESOPIPELINE
make
make install
popd

popd || exit
