"""Contained int."""


class ContainedInt(int):
    """Int that is contained and reused."""

    def __init__(self, *args, **kwargs):
        """__init__."""
        super().__init__()
        self.actual_int = int(*args, **kwargs)

    def __getattribute__(self, name):
        """__getattribute__."""
        if name in ("__dict__",):
            return object.__getattribute__(self, name)
        if name in self.__dict__:
            return self.__dict__[name]
        return getattr(self.actual_int, name)

    def __str__(self):
        """__str__."""
        return self.actual_int.__str__()

    def __repr__(self):
        """__repr__."""
        return self.actual_int.__repr__()

    def __iadd__(self, other):
        """__iadd__."""
        self.actual_int += other
        return self

    def __isub__(self, other):
        """__isub__."""
        self.actual_int -= other
        return self

    def __add__(self, other):
        """__add__."""
        return self.actual_int + other

    def __lt__(self, other):
        """__lt__."""
        return self.actual_int < other

    def __le__(self, other):
        """__le__."""
        return self.actual_int <= other

    def __gt__(self, other):
        """__gt__."""
        return self.actual_int > other

    def __ge__(self, other):
        """__ge__."""
        return self.actual_int >= other

    def __eq__(self, other):
        """__eq__."""
        return self.actual_int == other

    def __truediv__(self, other):
        """__truediv__."""
        return self.actual_int / other

    def __mul__(self, other):
        """__mul__."""
        return self.actual_int * other

    def __sub__(self, other):
        """__sub__."""
        return self.actual_int - other

    def __rsub__(self, other):
        """__rsub__."""
        return other - self.actual_int

    def __radd__(self, other):
        """__radd__."""
        return other + self.actual_int
